cheesecake.subprocess.STARTUPINFO

Package cheesecake :: Module subprocess :: Class STARTUPINFO |
[hide private]
[frames] | no frames]

## Class STARTUPINFO
source code

Class Variables | [hide private]
dwFlags |
hStdInput |
hStdOutput |
hStdError |

Class Variable Details | [hide private]

    ### dwFlags Value:
        0

    ### hStdInput Value:
        None

    ### hStdOutput Value:
        None

    ### hStdError Value:
        None